@@ -154,7 +154,10 @@ pub async fn connect_to_pubsub_with_capacity(
     tokio::spawn(async move {
         let mut pubsub_conn = client.get_async_connection().await.unwrap().into_pubsub();
 
-        pubsub_conn.subscribe(channel_name_incoming).await.unwrap();
+        pubsub_conn
+            .subscribe(channel_name_incoming)
+            .await
+            .expect("Was unable to subscribe to incoming channel in redis");
         let mut pubsub_stream = pubsub_conn.on_message();
 
         while let Some(msg) = pubsub_stream.next().await {
